@@ -48,7 +48,7 @@ convert_pir_out_to_long <- function(
   testthat::expect_equal(1, length(first_col_index))
 
 
-  df_long <- tidyr::pivot_longer(df, first_col_index:ncol(df))
+  df_long <- tidyr::pivot_longer(df, tidyr::all_of(first_col_index:ncol(df)))
   names(df_long) <- c(names(df_long)[1], "error_index", "error_value")
   testthat::expect_true("error_value" %in% names(df_long))
 
